==> must_cdk-0.0.2-py3-none-any.whl: package/API.md <==
# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### ApiGatewayToLambda <a name="ApiGatewayToLambda" id="must-cdk.ApiGatewayToLambda"></a>

#### Initializers <a name="Initializers" id="must-cdk.ApiGatewayToLambda.Initializer"></a>

```typescript
import { ApiGatewayToLambda } from 'must-cdk'

new ApiGatewayToLambda(scope: Construct, id: string, props: ApiGatewayToLambdaProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#must-cdk.ApiGatewayToLambda.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - represents the scope for all the resources. |
| <code><a href="#must-cdk.ApiGatewayToLambda.Initializer.parameter.id">id</a></code> | <code>string</code> | - this is a a scope-unique id. |
| <code><a href="#must-cdk.ApiGatewayToLambda.Initializer.parameter.props">props</a></code> | <code><a href="#must-cdk.ApiGatewayToLambdaProps">ApiGatewayToLambdaProps</a></code> | - user provided props for the construct. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="must-cdk.ApiGatewayToLambda.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

represents the scope for all the resources.

---

##### `id`<sup>Required</sup> <a name="id" id="must-cdk.ApiGatewayToLambda.Initializer.parameter.id"></a>

- *Type:* string

this is a a scope-unique id.

---

##### `props`<sup>Required</sup> <a name="props" id="must-cdk.ApiGatewayToLambda.Initializer.parameter.props"></a>

- *Type:* <a href="#must-cdk.ApiGatewayToLambdaProps">ApiGatewayToLambdaProps</a>

user provided props for the construct.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#must-cdk.ApiGatewayToLambda.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="must-cdk.ApiGatewayToLambda.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#must-cdk.ApiGatewayToLambda.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="must-cdk.ApiGatewayToLambda.isConstruct"></a>

```typescript
import { ApiGatewayToLambda } from 'must-cdk'

ApiGatewayToLambda.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="must-cdk.ApiGatewayToLambda.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.apiGateway">apiGateway</a></code> | <code>aws-cdk-lib.aws_apigateway.RestApi</code> | *No description.* |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.apiGatewayLogGroup">apiGatewayLogGroup</a></code> | <code>aws-cdk-lib.aws_logs.LogGroup</code> | *No description.* |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.lambdaFunction">lambdaFunction</a></code> | <code>aws-cdk-lib.aws_lambda.Function</code> | *No description.* |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.apiGatewayCloudWatchRole">apiGatewayCloudWatchRole</a></code> | <code>aws-cdk-lib.aws_iam.Role</code> | *No description.* |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.aRecord">aRecord</a></code> | <code>aws-cdk-lib.aws_route53.ARecord</code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="must-cdk.ApiGatewayToLambda.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGateway`<sup>Required</sup> <a name="apiGateway" id="must-cdk.ApiGatewayToLambda.property.apiGateway"></a>

```typescript
public readonly apiGateway: RestApi;
```

- *Type:* aws-cdk-lib.aws_apigateway.RestApi

---

##### `apiGatewayLogGroup`<sup>Required</sup> <a name="apiGatewayLogGroup" id="must-cdk.ApiGatewayToLambda.property.apiGatewayLogGroup"></a>

```typescript
public readonly apiGatewayLogGroup: LogGroup;
```

- *Type:* aws-cdk-lib.aws_logs.LogGroup

---

##### `lambdaFunction`<sup>Required</sup> <a name="lambdaFunction" id="must-cdk.ApiGatewayToLambda.property.lambdaFunction"></a>

```typescript
public readonly lambdaFunction: Function;
```

- *Type:* aws-cdk-lib.aws_lambda.Function

---

##### `apiGatewayCloudWatchRole`<sup>Optional</sup> <a name="apiGatewayCloudWatchRole" id="must-cdk.ApiGatewayToLambda.property.apiGatewayCloudWatchRole"></a>

```typescript
public readonly apiGatewayCloudWatchRole: Role;
```

- *Type:* aws-cdk-lib.aws_iam.Role

---

##### `aRecord`<sup>Optional</sup> <a name="aRecord" id="must-cdk.ApiGatewayToLambda.property.aRecord"></a>

```typescript
public readonly aRecord: ARecord;
```

- *Type:* aws-cdk-lib.aws_route53.ARecord

---


## Structs <a name="Structs" id="Structs"></a>

### ApiGatewayToLambdaProps <a name="ApiGatewayToLambdaProps" id="must-cdk.ApiGatewayToLambdaProps"></a>

#### Initializer <a name="Initializer" id="must-cdk.ApiGatewayToLambdaProps.Initializer"></a>

```typescript
import { ApiGatewayToLambdaProps } from 'must-cdk'

const apiGatewayToLambdaProps: ApiGatewayToLambdaProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.apiGatewayProps">apiGatewayProps</a></code> | <code>any</code> | Optional user-provided props to override the default props for the API. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.createUsagePlan">createUsagePlan</a></code> | <code>boolean</code> | Whether to create a Usage Plan attached to the API. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.domainNameProps">domainNameProps</a></code> | <code>aws-cdk-lib.aws_apigateway.DomainNameProps</code> | Optional custom domain configuration for API Gateway. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.existingLambdaObj">existingLambdaObj</a></code> | <code>aws-cdk-lib.aws_lambda.Function</code> | Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.hostedZone">hostedZone</a></code> | <code>aws-cdk-lib.aws_route53.IHostedZone</code> | Optional Route53 hosted zone to create alias record for the custom domain. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.lambdaFunctionProps">lambdaFunctionProps</a></code> | <code>aws-cdk-lib.aws_lambda.FunctionProps</code> | User provided props to override the default props for the Lambda function. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.logGroupProps">logGroupProps</a></code> | <code>aws-cdk-lib.aws_logs.LogGroupProps</code> | *No description.* |

---

##### `apiGatewayProps`<sup>Optional</sup> <a name="apiGatewayProps" id="must-cdk.ApiGatewayToLambdaProps.property.apiGatewayProps"></a>

```typescript
public readonly apiGatewayProps: any;
```

- *Type:* any

Optional user-provided props to override the default props for the API.

---

##### `createUsagePlan`<sup>Optional</sup> <a name="createUsagePlan" id="must-cdk.ApiGatewayToLambdaProps.property.createUsagePlan"></a>

```typescript
public readonly createUsagePlan: boolean;
```

- *Type:* boolean

Whether to create a Usage Plan attached to the API.

Must be true if
apiGatewayProps.defaultMethodOptions.apiKeyRequired is true

---

##### `domainNameProps`<sup>Optional</sup> <a name="domainNameProps" id="must-cdk.ApiGatewayToLambdaProps.property.domainNameProps"></a>

```typescript
public readonly domainNameProps: DomainNameProps;
```

- *Type:* aws-cdk-lib.aws_apigateway.DomainNameProps
- *Default:* no custom domain

Optional custom domain configuration for API Gateway.

---

##### `existingLambdaObj`<sup>Optional</sup> <a name="existingLambdaObj" id="must-cdk.ApiGatewayToLambdaProps.property.existingLambdaObj"></a>

```typescript
public readonly existingLambdaObj: Function;
```

- *Type:* aws-cdk-lib.aws_lambda.Function
- *Default:* None

Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.

---

##### `hostedZone`<sup>Optional</sup> <a name="hostedZone" id="must-cdk.ApiGatewayToLambdaProps.property.hostedZone"></a>

```typescript
public readonly hostedZone: IHostedZone;
```

- *Type:* aws-cdk-lib.aws_route53.IHostedZone
- *Default:* no Route53 alias record created

Optional Route53 hosted zone to create alias record for the custom domain.

---

##### `lambdaFunctionProps`<sup>Optional</sup> <a name="lambdaFunctionProps" id="must-cdk.ApiGatewayToLambdaProps.property.lambdaFunctionProps"></a>

```typescript
public readonly lambdaFunctionProps: FunctionProps;
```

- *Type:* aws-cdk-lib.aws_lambda.FunctionProps

User provided props to override the default props for the Lambda function.

---

##### `logGroupProps`<sup>Optional</sup> <a name="logGroupProps" id="must-cdk.ApiGatewayToLambdaProps.property.logGroupProps"></a>

```typescript
public readonly logGroupProps: LogGroupProps;
```

- *Type:* aws-cdk-lib.aws_logs.LogGroupProps

---

==> must_cdk-0.0.3-py3-none-any.whl: package/API.md <==
# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### ApiGatewayToLambda <a name="ApiGatewayToLambda" id="must-cdk.ApiGatewayToLambda"></a>

#### Initializers <a name="Initializers" id="must-cdk.ApiGatewayToLambda.Initializer"></a>

```typescript
import { ApiGatewayToLambda } from 'must-cdk'

new ApiGatewayToLambda(scope: Construct, id: string, props: ApiGatewayToLambdaProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#must-cdk.ApiGatewayToLambda.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - represents the scope for all the resources. |
| <code><a href="#must-cdk.ApiGatewayToLambda.Initializer.parameter.id">id</a></code> | <code>string</code> | - this is a a scope-unique id. |
| <code><a href="#must-cdk.ApiGatewayToLambda.Initializer.parameter.props">props</a></code> | <code><a href="#must-cdk.ApiGatewayToLambdaProps">ApiGatewayToLambdaProps</a></code> | - user provided props for the construct. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="must-cdk.ApiGatewayToLambda.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

represents the scope for all the resources.

---

##### `id`<sup>Required</sup> <a name="id" id="must-cdk.ApiGatewayToLambda.Initializer.parameter.id"></a>

- *Type:* string

this is a a scope-unique id.

---

##### `props`<sup>Required</sup> <a name="props" id="must-cdk.ApiGatewayToLambda.Initializer.parameter.props"></a>

- *Type:* <a href="#must-cdk.ApiGatewayToLambdaProps">ApiGatewayToLambdaProps</a>

user provided props for the construct.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#must-cdk.ApiGatewayToLambda.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="must-cdk.ApiGatewayToLambda.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#must-cdk.ApiGatewayToLambda.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="must-cdk.ApiGatewayToLambda.isConstruct"></a>

```typescript
import { ApiGatewayToLambda } from 'must-cdk'

ApiGatewayToLambda.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="must-cdk.ApiGatewayToLambda.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.apiGateway">apiGateway</a></code> | <code>aws-cdk-lib.aws_apigateway.RestApi</code> | *No description.* |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.apiGatewayLogGroup">apiGatewayLogGroup</a></code> | <code>aws-cdk-lib.aws_logs.LogGroup</code> | *No description.* |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.lambdaFunction">lambdaFunction</a></code> | <code>aws-cdk-lib.aws_lambda.Function</code> | *No description.* |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.apiGatewayCloudWatchRole">apiGatewayCloudWatchRole</a></code> | <code>aws-cdk-lib.aws_iam.Role</code> | *No description.* |
| <code><a href="#must-cdk.ApiGatewayToLambda.property.aRecord">aRecord</a></code> | <code>aws-cdk-lib.aws_route53.ARecord</code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="must-cdk.ApiGatewayToLambda.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `apiGateway`<sup>Required</sup> <a name="apiGateway" id="must-cdk.ApiGatewayToLambda.property.apiGateway"></a>

```typescript
public readonly apiGateway: RestApi;
```

- *Type:* aws-cdk-lib.aws_apigateway.RestApi

---

##### `apiGatewayLogGroup`<sup>Required</sup> <a name="apiGatewayLogGroup" id="must-cdk.ApiGatewayToLambda.property.apiGatewayLogGroup"></a>

```typescript
public readonly apiGatewayLogGroup: LogGroup;
```

- *Type:* aws-cdk-lib.aws_logs.LogGroup

---

##### `lambdaFunction`<sup>Required</sup> <a name="lambdaFunction" id="must-cdk.ApiGatewayToLambda.property.lambdaFunction"></a>

```typescript
public readonly lambdaFunction: Function;
```

- *Type:* aws-cdk-lib.aws_lambda.Function

---

##### `apiGatewayCloudWatchRole`<sup>Optional</sup> <a name="apiGatewayCloudWatchRole" id="must-cdk.ApiGatewayToLambda.property.apiGatewayCloudWatchRole"></a>

```typescript
public readonly apiGatewayCloudWatchRole: Role;
```

- *Type:* aws-cdk-lib.aws_iam.Role

---

##### `aRecord`<sup>Optional</sup> <a name="aRecord" id="must-cdk.ApiGatewayToLambda.property.aRecord"></a>

```typescript
public readonly aRecord: ARecord;
```

- *Type:* aws-cdk-lib.aws_route53.ARecord

---


## Structs <a name="Structs" id="Structs"></a>

### ApiGatewayToLambdaProps <a name="ApiGatewayToLambdaProps" id="must-cdk.ApiGatewayToLambdaProps"></a>

#### Initializer <a name="Initializer" id="must-cdk.ApiGatewayToLambdaProps.Initializer"></a>

```typescript
import { ApiGatewayToLambdaProps } from 'must-cdk'

const apiGatewayToLambdaProps: ApiGatewayToLambdaProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.apiGatewayProps">apiGatewayProps</a></code> | <code>any</code> | Optional user-provided props to override the default props for the API. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.createUsagePlan">createUsagePlan</a></code> | <code>boolean</code> | Whether to create a Usage Plan attached to the API. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.customDomainName">customDomainName</a></code> | <code>string</code> | Optional custom domain configuration for API Gateway. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.existingLambdaObj">existingLambdaObj</a></code> | <code>aws-cdk-lib.aws_lambda.Function</code> | Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.hostedZone">hostedZone</a></code> | <code>aws-cdk-lib.aws_route53.IHostedZone</code> | Optional Route53 hosted zone to create alias record for the custom domain. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.lambdaFunctionProps">lambdaFunctionProps</a></code> | <code>aws-cdk-lib.aws_lambda.FunctionProps</code> | User provided props to override the default props for the Lambda function. |
| <code><a href="#must-cdk.ApiGatewayToLambdaProps.property.logGroupProps">logGroupProps</a></code> | <code>aws-cdk-lib.aws_logs.LogGroupProps</code> | *No description.* |

---

##### `apiGatewayProps`<sup>Optional</sup> <a name="apiGatewayProps" id="must-cdk.ApiGatewayToLambdaProps.property.apiGatewayProps"></a>

```typescript
public readonly apiGatewayProps: any;
```

- *Type:* any

Optional user-provided props to override the default props for the API.

---

##### `createUsagePlan`<sup>Optional</sup> <a name="createUsagePlan" id="must-cdk.ApiGatewayToLambdaProps.property.createUsagePlan"></a>

```typescript
public readonly createUsagePlan: boolean;
```

- *Type:* boolean

Whether to create a Usage Plan attached to the API.

Must be true if
apiGatewayProps.defaultMethodOptions.apiKeyRequired is true

---

##### `customDomainName`<sup>Optional</sup> <a name="customDomainName" id="must-cdk.ApiGatewayToLambdaProps.property.customDomainName"></a>

```typescript
public readonly customDomainName: string;
```

- *Type:* string
- *Default:* no custom domain

Optional custom domain configuration for API Gateway.

---

##### `existingLambdaObj`<sup>Optional</sup> <a name="existingLambdaObj" id="must-cdk.ApiGatewayToLambdaProps.property.existingLambdaObj"></a>

```typescript
public readonly existingLambdaObj: Function;
```

- *Type:* aws-cdk-lib.aws_lambda.Function
- *Default:* None

Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.

---

##### `hostedZone`<sup>Optional</sup> <a name="hostedZone" id="must-cdk.ApiGatewayToLambdaProps.property.hostedZone"></a>

```typescript
public readonly hostedZone: IHostedZone;
```

- *Type:* aws-cdk-lib.aws_route53.IHostedZone
- *Default:* no Route53 alias record created

Optional Route53 hosted zone to create alias record for the custom domain.

---

##### `lambdaFunctionProps`<sup>Optional</sup> <a name="lambdaFunctionProps" id="must-cdk.ApiGatewayToLambdaProps.property.lambdaFunctionProps"></a>

```typescript
public readonly lambdaFunctionProps: FunctionProps;
```

- *Type:* aws-cdk-lib.aws_lambda.FunctionProps

User provided props to override the default props for the Lambda function.

---

##### `logGroupProps`<sup>Optional</sup> <a name="logGroupProps" id="must-cdk.ApiGatewayToLambdaProps.property.logGroupProps"></a>

```typescript
public readonly logGroupProps: LogGroupProps;
```

- *Type:* aws-cdk-lib.aws_logs.LogGroupProps

---
